@@ -1,6 +1,7 @@
 from http.client import NotConnected, IncompleteRead, ImproperConnectionState, CannotSendRequest, CannotSendHeader, \
     ResponseNotReady, BadStatusLine
 from httplib2 import HttpLib2Error
+from wg_utilities.helpers.dict_to_object import DictToObject
 
 HASS_DIR = '/home/hass/.homeassistant/'
 INDENT = '    '
@@ -17,3 +18,10 @@ RETRIABLE_EXCEPTIONS = (HttpLib2Error, IOError, NotConnected,
                         ResponseNotReady, BadStatusLine)
 
 RETRIABLE_STATUS_CODES = (500, 502, 503, 504)
+
+OS = DictToObject({
+    'WINDOWS': 'Windows',
+    'MAC_OS': 'Darwin',
+    'LINUX': 'Linux',
+    'JAVA': 'Java'
+})
